use anyhow::anyhow;
use clap::arg;
use prymn_agent::{self_update, server};

fn main() -> anyhow::Result<()> {
    if std::env::consts::OS != "linux" {
        return Err(anyhow!("platform is not linux!"));
    }

    tracing_subscriber::fmt().init();

    let command = clap::Command::new(env!("CARGO_BIN_NAME"))
        .version(env!("CARGO_PKG_VERSION"))
        .arg(arg!(-d --daemon "Run agent as daemon").exclusive(true))
        .arg(arg!(--install <TOKEN> "Install this agent binary to the system").exclusive(true))
        .arg_required_else_help(true)
        .try_get_matches()
        .unwrap_or_else(|e| e.exit());

    if command.get_flag("daemon") {
        tracing::info!("running as daemon");
        server::main()
    } else if let Some(token) = command.get_one::<String>("install") {
        tracing::info!("running install mode");
        self_update::install(token)
    } else {
        unreachable!()
    }
}
